<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Canlı ortam algılandı. Lütfen değiştirmek istediğiniz sistemin
kök bölümünü seçin (yalnızca linux bölümleri görüntülenir)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Kernel parameters</source>
        <translation>Çekirdek çarpanları</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Menüyü görüntülemeden hemen önyükleme yapmak için &apos;0&apos; veya süresiz olarak beklemek için &apos;-1&apos; olarak ayarlayın</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Menu timeout</source>
        <translation>Menü zaman aşımı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="75"/>
        <source>Boot to</source>
        <translation>Önyükleme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Alt menüleri olmayan basitleştirilmiş menü yapısını kullanın</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Düz menüleri kullan (alt menüler yok)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>seconds</source>
        <translation>saniye</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Bu seçenek etkinleştirildiğinde, grub önyükleme menüsünden seçtiğiniz giriş biçimi, sonraki önyüklemeler için öntanımlı olarak kaydedilecektir.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Enable saving last boot choice</source>
        <translation>Son önyükleme seçimini kaydetmeyi etkinleştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Background</source>
        <translation>Arkaplan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Image</source>
        <translation>Resim</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <location filename="../mainwindow.ui" line="270"/>
        <source>Enable theme</source>
        <translation>Temayı etkinleştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Splash</source>
        <translation>Açılış</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Preview</source>
        <translation>Önizleme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Messages</source>
        <translation>İletiler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>Very detailed</source>
        <translation>Çok ayrıntılı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Detailed (default setting)</source>
        <translation>Ayrıntılı (öntanımlı ayar)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Limited</source>
        <translation>Sınırlı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <source>Display log</source>
        <translation>Günlüğü görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="536"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Still running</source>
        <translation>Hala çalışıyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Installing bootsplash, please wait</source>
        <translation>bootsplash kuruluyor, lütfen bekleyin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Updating sources</source>
        <translation>kaynaklar güncelleniyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <source>Installing</source>
        <translation>Kuruluyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Could not install the bootsplash.</source>
        <translation>bootsplash kurulamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>Cannot continue</source>
        <translation>Devam edilemez</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Hiçbir şey seçilmedi, önyükleme seçeneklerini değiştiremez. Çıkılıyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Could not create a temporary folder</source>
        <translation>Geçici klasör oluşturulamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Chroot ortamı oluşturulamıyor, önyükleme seçenekleri değiştirilemiyor. Çıkılıyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Updating configuration, please wait</source>
        <translation>Yapılandırma güncelleniyor, lütfen bekleyin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Updating initramfs...</source>
        <translation>İnitramfs güncelleniyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <location filename="../mainwindow.cpp" line="891"/>
        <source>Updating grub...</source>
        <translation>Grub güncelleniyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Changes have been successfully applied.</source>
        <translation>Değişiklikler başarıyla uygulandı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ortak başlangıç tercihlerinin seçimi için program</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="656"/>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="658"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>MX Boot Options</source>
        <translation>MX Açılış Seçenekleri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="716"/>
        <source>Running in a Virtual Machine</source>
        <translation>Sanal Makinede Çalışıyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="717"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Mevcut sisteminiz bir Sanal Makinede çalışıyor,
Plymouth bootsplash sınırlı bir şekilde çalışacak, ayrıca tema önizlemesi yapamayacaksınız</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Plymouth packages not installed</source>
        <translation>Playmouth paketleri kurulmadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth paketleri şu anda yüklü değil.
Onları kurmak için devam etmeye hazır mısın?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Resimler (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>Press any key to close</source>
        <translation>Kapatmak için herhangi bir tuşa basın</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Log not found</source>
        <translation>Kayıt bulunamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Could not find log at </source>
        <translation>Şurada günlük bulunamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Needs reboot</source>
        <translation>Yeniden başlatma gerekli</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth henüz kuruldu, önizlemeleri görüntüleyebilmek için önce yeniden başlatmanız gerekebilir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <source>Click to select theme</source>
        <translation>Temayı seçmek için tıklayın</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ortak başlangıç tercihlerinin seçimi için program</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Görünüşe göre root olarak girmişsiniz, lütfen çıkın ve bu programı kullanmak için normal kullanıcı olarak girin. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>Select image to display in bootloader</source>
        <translation>Önyükleyicide görüntülenecek görseli seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Select GRUB theme</source>
        <translation>Grub temasını seçin</translation>
    </message>
</context>
</TS>
